@@ -10,7 +10,7 @@ from .config import (
     DEFAULT_TIMEOUT,
     MULTI_DOCUMENT_LIMIT,
 )
-from .models import Detail, Document, MultiScanResult, ScanResult
+from .models import Detail, Document, MultiScanResult, QuotaResponse, ScanResult
 
 
 def load_detail(resp: Response) -> Detail:
@@ -104,10 +104,7 @@ class GGClient:
         extra_headers: Dict[str, str] = None,
         **kwargs
     ) -> Response:
-        if version:
-            endpoint = urllib.parse.urljoin(version + "/", endpoint)
-
-        url = urllib.parse.urljoin(self.base_uri, endpoint)
+        url = self._url_from_endpoint(endpoint, version)
 
         headers = (
             {**self.session.headers, **extra_headers}
@@ -118,6 +115,12 @@ class GGClient:
             method=method, url=url, timeout=self.timeout, headers=headers, **kwargs
         )
 
+    def _url_from_endpoint(self, endpoint: str, version: Optional[str]) -> str:
+        if version:
+            endpoint = urllib.parse.urljoin(version + "/", endpoint)
+
+        return urllib.parse.urljoin(self.base_uri + "/", endpoint)
+
     def get(
         self,
         endpoint: str,
@@ -241,3 +244,28 @@ class GGClient:
         obj.status_code = resp.status_code
 
         return obj
+
+    def quota_overview(
+        self,
+        extra_headers: Optional[Dict[str, str]] = None,
+    ) -> Union[Detail, QuotaResponse]:
+        """
+        content_scan handles the /scan endpoint of the API
+
+        :param extra_headers: additional headers to add to the request
+        :return: Detail or Quota response and status code
+        """
+
+        resp = self.get(
+            endpoint="quotas",
+            extra_headers=extra_headers,
+        )
+
+        if is_ok(resp):
+            obj = QuotaResponse.SCHEMA.load(resp.json())
+        else:
+            obj = load_detail(resp)
+
+        obj.status_code = resp.status_code
+
+        return obj
